@@ -1,4 +1,4 @@
-#' `save_xlsx` is a shortcut to save a Tatoo_table direclty to local .xlsx
+#' `save_xlsx` is a shortcut to save a Tatoo_table directly to local .xlsx
 #' file.
 #'
 #' @param outfile path/name of the output file
@@ -15,7 +15,7 @@ save_xlsx <- function(
   overwrite = FALSE,
   ...
 ){
-  assert_that(purrr::is_scalar_character(outfile))
+  assert_that(rlang::is_scalar_character(outfile))
   assert_that(is.flag(overwrite))
 
   UseMethod('save_xlsx')
