@@ -46,6 +46,7 @@ all_are_distinct <- function(x, empty_value = FALSE, silent = FALSE){
 
 
 
+
 # assert valid ------------------------------------------------------------
 
 is_valid <- function(x, ...) {
@@ -67,6 +68,8 @@ assert_valid <- function(dat, ...){
 }
 
 
+
+
 assert_valid_error  <- function(obj) {
   msg <- sprintf(
     'A validity check failed for object of class: %s.',
@@ -79,12 +82,13 @@ assert_valid_error  <- function(obj) {
 
 
 
+
 # assertions --------------------------------------------------------------
 
 #' Check if object is of a certain class
 #'
-#' These functions are desinged to be used in combination with the assertthat
-#' pacakge
+#' These functions are designed to be used in combination with the assertthat
+#' package
 #'
 #' is_class returns TRUE/FALSE. It comes with a on_failure function and
 #' is designed to be used in conjunction with the assertthat package.
@@ -100,6 +104,8 @@ is_class <- function(dat, class){
 }
 
 
+
+
 on_failure(is_class) <- function(call, env){
   #print(call)
   #class = eval(env$class)
@@ -116,6 +122,8 @@ assert_class <- function(dat, class){
 }
 
 
+
+
 #' @rdname is_class
 `%assert_class%` <- function(dat, class){
   assert_class(dat = dat, class = class)
@@ -136,6 +144,8 @@ is_any_class <- function(dat, choices){
 }
 
 
+
+
 on_failure(is_any_class) <- function(call, env){
   choices = paste(eval(call$choices), collapse=", ")
   paste("Input must be an object of any of the following classes:", choices)
@@ -188,6 +198,8 @@ is_col_classes <- function(dat, classes, method = 'identical'){
 }
 
 
+
+
 assertthat::on_failure(is_col_classes) <- function(call, env){
   dat     <- eval(call$dat)
   classes <- eval(call$classes)
@@ -245,7 +257,14 @@ cfun <- function(x){
   return(res)
 }
 
+
+
+
 as.numeric2   <- function(x) as.numeric(as.character(x))
+
+
+
+
 as.integer2   <- function(x) as.integer(as.character(x))
 
 
@@ -282,7 +301,6 @@ all_with_warning <- function(dat){
 
 
 
-
 df_round <- function(dat, digits = 0){
   assert_that(is.number(digits))
   numcols <- names(dat)[unlist(lapply(dat, is.numeric))]
@@ -325,7 +343,6 @@ df_typecast_all <- function(dat, from = 'factor', to = 'character'){
 
 
 
-
 #' Check if a value looks like integer
 #'
 #' @param x ...
@@ -364,9 +381,47 @@ str_nobreak <- function(x){
 
 
 
+
 condition <- function(subclass, message, call = sys.call(-1), ...) {
   structure(
     class = c(subclass, "condition"),
     list(message = message, call = call, ...)
   )
 }
+
+
+
+
+#' Rearrange vector based on priorities
+#'
+#' Shoves elements of a character vector to the front or back.
+#' Throws a warning if any elements of `high` or `low` are not present in `x`.
+#'
+#' @param x a character vector
+#' @param high elements to be put to the front
+#' @param low elements to be put to the back
+#'
+#' @return a reordered vector
+#'
+vec_prioritise <- function(x, high = NULL, low = NULL){
+  low_not_x  <- low[!low %in% x]
+  high_not_x <- high[!high %in% x]
+
+  if(!all(low  %in% x)) {
+    warning(
+      'Not all "low" are present in "x": ',
+      paste(low_not_x, collapse = ' '))
+  }
+  if(!all(high %in% x)){
+    warning(
+      'Not all "high" are present in "x": ',
+      paste(high_not_x, collapse = ' '))
+  }
+
+  low      <- low[low %in% x]
+  high     <- high[high %in% x]
+  mid      <- x[!x %in% c(high, low)]
+  ordered  <- c(high, mid, low)
+
+  return(ordered)
+}
