@@ -1,8 +1,8 @@
 # Utils -------------------------------------------------------------------
 
-#' Sanitze excel sheet names
+#' Sanitize excel sheet names
 #'
-#' Convert a vactor to valid excel sheet names by:
+#' Convert a vector to valid excel sheet names by:
 #' * trimming names down to 31 characters,
 #' * ensuring each element of the vector is unique,
 #' * and removing the illegal characters \code{ \ / * [ ] : ?}.
@@ -24,8 +24,8 @@
 #'
 #'   # [1] "a very_ long  vector_ containi0" "a very_ long  vector_ containi1"
 sanitize_excel_sheet_names <- function(x, replace = '_'){
-  assert_that(purrr::is_vector(x))
-  assert_that(purrr::is_scalar_character(replace))
+  assert_that(rlang::is_vector(x))
+  assert_that(rlang::is_scalar_character(replace))
   x <- as.character(x)
 
   invalid_chars_regex <- "\\[|\\]|\\*|\\?|:|\\/|\\\\"
@@ -68,14 +68,14 @@ get_final_wb_row <- function(wb, sheet){
 #'
 #' @param dat A \code{list} of objects that can be printed, usually \code{data.frame}s
 #'   or \code{Tatoo_table}s
-#' @param indent a scalar character specifing the indent symbols (e.g. "  ")
-#' @param sep1 \code{character} or \code{numeric}. Seperator above the first and
+#' @param indent a scalar character specifying the indent symbols (e.g. "  ")
+#' @param sep1 \code{character} or \code{numeric}. Separator above the first and
 #'   below the last table.  If character a sep line is created using this
 #'   character (i.e. ------). If numeric, that many blank rows are inserted.
 #' @param sep2 \code{character} or \code{numeric}. Spacing between the tables.
 #'   Like \code{sep1}
 #' @param headings \code{character} vector of the same length as \code{dat},
-#'   specifiying headings to be inserted above each table.
+#'   specifying headings to be inserted above each table.
 #' @param ... passed on to \code{\link{print}}
 #'
 #' @return \code{dat} (invisibly)
@@ -98,7 +98,7 @@ print_several_tables <- function(
     purrr::map(function(x) purrr::map_int(x, nchar)) %>%
     unlist() %>%
     max()
-  assert_that(purrr::is_scalar_integer(tables_width))
+  assert_that(rlang::is_scalar_integer(tables_width))
 
 
   # Define sepperators
